require 'rspec'
require 'active_hash'
require_relative '../../lib/active_hash_ext'

describe 'ActiveHashExt' do

  before do

    class TestHash <  ActiveHash::Base
      include ActiveHashExt
      fields :name, :age
    end

    TestHash.delete_all
  end

  it '#update' do

    test_hash = TestHash.new
    test_hash.update(age: 34, name: 'Sam')
    expect(test_hash.age).to eq 34
    expect(test_hash.name).to eq 'Sam'
  end

  it '#destroy_all' do
    TestHash.create(name: 'Jane', age: 56)
    expect(TestHash.count).to eq 1
    TestHash.destroy_all
    expect(TestHash.count).to eq 0
  end

  context 'read_schema' do

    it 'returns attributes from schema file' do
      expect(TestHash.read_schema('custodians', File.new('schema.rb', 'r'))).to eq [:name, :created_at, :updated_at]
    end

    it 'when passed to fields it will set attributes on class from schema' do
      class SchemaHash <  ActiveHash::Base
        include ActiveHashExt
        fields *read_schema('custodians', File.new('schema.rb', 'r'))
      end
      SchemaHash.create(name: 'Fred')
      expect(SchemaHash.first.name).to eq 'Fred'
    end

    it 'will raise an exception if table does not exist' do
      -> {TestHash.read_schema('custodian', File.new('schema.rb', 'r'))}.should raise_error('Table Name not Found!')
    end

  end

end